@@ -3,7 +3,7 @@
 use crate::{ArcInterval, DhtArcSet};
 
 pub fn ascii(s: &str) -> DhtArcSet {
-    let mut wints = Vec::<ArcInterval>::new();
+    let mut arcs = Vec::<ArcInterval>::new();
     let mut i: usize = 0;
 
     loop {
@@ -21,10 +21,10 @@ pub fn ascii(s: &str) -> DhtArcSet {
             i += 1
         }
         let end = i - 1;
-        wints.push(ArcInterval::new(start as u32, end as u32));
+        arcs.push(ArcInterval::new(start as u32, end as u32));
     }
 
-    wints.into()
+    arcs.as_slice().into()
 }
 
 #[cfg(test)]
@@ -37,10 +37,13 @@ mod tests {
     #[test]
     fn sanity() {
         assert_eq!(
-            DhtArcSet::from(vec![
-                ArcInterval::new(0, 2),
-                ArcInterval::new(u32::MAX - 2, u32::MAX)
-            ])
+            DhtArcSet::from(
+                vec![
+                    ArcInterval::new(0, 2),
+                    ArcInterval::new(u32::MAX - 2, u32::MAX)
+                ]
+                .as_slice()
+            )
             .intervals(),
             vec![ArcInterval::new(u32::MAX - 2, 2)]
         );
